==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/router/src/rest_router/src/rest_router_status.h <==
/*
  Copyright (c) 2019, 2021, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQLROUTER_REST_ROUTER_STATUS_INCLUDED
#define MYSQLROUTER_REST_ROUTER_STATUS_INCLUDED

#include <ctime>

#include "mysqlrouter/rest_api_component.h"

class RestRouterStatus : public RestApiHandler {
 public:
  static constexpr const char path_regex[] = "^/router/status$";

  RestRouterStatus(const std::string &require_realm)
      : RestApiHandler(require_realm, HttpMethod::Get),
        running_since_(std::chrono::system_clock::now()),
        last_modified_(time(nullptr)) {}

  bool on_handle_request(HttpRequest &req, const std::string &base_path,
                         const std::vector<std::string> &path_matches) override;

 private:
  std::chrono::system_clock::time_point running_since_;

  time_t last_modified_;
};

#endif

==> mysql-8.0_8.0.44.orig.tar.gz: mysql-8.0.44/router/src/rest_router/src/rest_router_status.h <==
/*
  Copyright (c) 2019, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQLROUTER_REST_ROUTER_STATUS_INCLUDED
#define MYSQLROUTER_REST_ROUTER_STATUS_INCLUDED

#include <ctime>

#include "mysqlrouter/rest_api_component.h"

class RestRouterStatus : public RestApiHandler {
 public:
  static constexpr const char path_regex[] = "^/router/status$";

  RestRouterStatus(const std::string &require_realm)
      : RestApiHandler(require_realm, HttpMethod::Get),
        running_since_(std::chrono::system_clock::now()),
        last_modified_(time(nullptr)) {}

  bool on_handle_request(HttpRequest &req, const std::string &base_path,
                         const std::vector<std::string> &path_matches) override;

 private:
  std::chrono::system_clock::time_point running_since_;

  time_t last_modified_;
};

#endif
